Thyestes it a timer microservice. Listens on topics for specific
messages, starts a timer when such a messages has been received and
publishes a predefined message after the timer expired.

.. figure:: img/Microservice%20Overview.png
   :alt: Pelops Overview

   Pelops Overview

``Thyestes`` is part of the collection of mqtt based microservices
`pelops <https://gitlab.com/pelops>`__. An overview on the microservice
architecture and examples can be found at
(http://gitlab.com/pelops/pelops).

